function [ r_bwimage ] = draw_line( i_bwimage, i_point1, i_point2 )
%DRAW_LINE
%   Funkce vykreslí černou úsečku mezi body i_point1 a i_point2 do
%   i_bwimage a vysledek vratí v r_bwimage
%   i_bwimage - matice vstupního binárního snímku
%   i_point1  - souřadnice bodu
%   i_point2  - souřadnice bodu
%   r_bwimage - výsledná matice binárního snímku
    r_bwimage = i_bwimage;
    m = 100;
    t = linspace(0,1,m);
    points = zeros(m,2);
    for i=1:1:m
        points(i,:) = t(i)*i_point1 + (1-t(i))*i_point2;
    end
    points = round(points);
    for i=1:1:m
        r_bwimage(points(i,1),points(i,2)) = 0;
    end
    
end

